"""
NGET (Nested Get) - A simple package for safely retrieving nested values from data structures using a sequence of keys or indexes.
"""

from .nget import nget

__version__ = "0.0.2"
__all__ = ["nget"]
